darkhistory.utilities.check_err — DarkHistory documentation

# darkhistory.utilities.check_err

`darkhistory.utilities.` `check_err`(val, err, epsrel)

  Checks the relative error given a tolerance.

  Parameters: | val : float or ndarray The computed value. err : float or ndarray The computed error. epsrel : float The target tolerance.
  Returns: | None

#### Previous topic

darkhistory.utilities.bernoulli

#### Next topic

darkhistory.utilities.compare_arr

### This Page

Show Source